coderspace_network library
Classes
- CoderClient
- Main class to make HTTP requests using Dio.
- CoderException
- Handles Dio exceptions and maps them to user-friendly error messages.
-
CoderResult<
T> - A simple wrapper to handle both success and failure responses generically.
Functions
-
ensureList<
T> (dynamic data, T parser(dynamic)) → List< T> - Normalizes API responses by wrapping single objects as a list.