CoderResult<T> class

A simple wrapper to handle both success and failure responses generically.

Constructors

CoderResult.failure(String error)
Failure constructor
factory
CoderResult.success(T data)
Success constructor
factory

Properties

data → T?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Returns true if the request was successful
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited