CoderResult<T> class
A simple wrapper to handle both success and failure responses generically.
Constructors
- CoderResult.failure(String error)
-
Failure constructor
factory
- CoderResult.success(T data)
-
Success constructor
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited